@@ -1,13 +1,13 @@
 package XML::GRDDL::Transformation::Hardcoded::eRDF;
 
 use 5.008;
-use common::sense;
+use strict;
 use base qw[
 	XML::GRDDL::Transformation::Hardcoded
 	XML::GRDDL::Transformation::XSLT_1
-	];
+];
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 our $content;
 
 BEGIN
@@ -43,13 +43,23 @@ L<http://purl.org/NET/erdf/extract-rdf.xsl>.
 
 Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
-=head1 COPYRIGHT
+Ian Davis L<http://purl.org/NET/iand>.
 
-Copyright 2011 Toby Inkster
+=head1 COPYRIGHT AND LICENCE
+
+Portions by Ian Davis, in the public domain.
+
+Copyright 2011-2012 Toby Inkster
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
+=head1 DISCLAIMER OF WARRANTIES
+
+THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
+WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
+MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+
 =cut
 
 __DATA__
