@@ -1,13 +1,13 @@
 package XML::GRDDL::Transformation::RDF_EASE;
 
 use 5.008;
-use common::sense;
+use strict;
 use base qw[XML::GRDDL::Transformation];
 
 use Scalar::Util qw[blessed];
 use XML::GRDDL::Transformation::RDF_EASE::Functional qw[:standard];
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 
 sub transform
 {
@@ -60,9 +60,15 @@ L<XML::GRDDL::Transformation::RDF_EASE::Functional>.
 
 Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENCE
 
-Copyright 2008-2011 Toby Inkster
+Copyright 2008-2012 Toby Inkster
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
+
+=head1 DISCLAIMER OF WARRANTIES
+
+THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
+WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
+MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
